==> kaidan-0.5.0.tar.xz: kaidan-0.5.0/src/CredentialsValidator.h <==
/*
 *  Kaidan - A user-friendly XMPP client for every device!
 *
 *  Copyright (C) 2016-2020 Kaidan developers and contributors
 *  (see the LICENSE file for a full list of copyright authors)
 *
 *  Kaidan is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  In addition, as a special exception, the author of Kaidan gives
 *  permission to link the code of its release with the OpenSSL
 *  project's "OpenSSL" library (or with modified versions of it that
 *  use the same license as the "OpenSSL" library), and distribute the
 *  linked executables. You must obey the GNU General Public License in
 *  all respects for all of the code used other than "OpenSSL". If you
 *  modify this file, you may extend this exception to your version of
 *  the file, but you are not obligated to do so.  If you do not wish to
 *  do so, delete this exception statement from your version.
 *
 *  Kaidan is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Kaidan.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef CREDENTIALSVALIDATOR_H
#define CREDENTIALSVALIDATOR_H

#include <QObject>

/**
 * This is a validator for XMPP account credentials.
 */
class CredentialsValidator : public QObject
{
	Q_OBJECT

public:
	CredentialsValidator(QObject *parent = nullptr);

	/**
	 * Returns true if the given string is a valid JID of an XMPP account.
	 *
	 * @param jid JID to be validated
	 */
	Q_INVOKABLE static bool isAccountJidValid(const QString &jid);

	/**
	 * Returns true if the given string is a valid username.
	 *
	 * @param username username to be validated
	 */
	Q_INVOKABLE static bool isUsernameValid(const QString &username);

	/**
	 * Returns true if the given string is a valid server.
	 *
	 * @param username server to be validated
	 */
	Q_INVOKABLE static bool isServerValid(const QString &server);

	/**
	 * Returns true if the given string is a valid password.
	 *
	 * @param password password to be validated
	 */
	Q_INVOKABLE static bool isPasswordValid(const QString &password);
};

#endif // CREDENTIALSVALIDATOR_H

==> kaidan-0.6.0.tar.xz: kaidan-0.6.0/src/CredentialsValidator.h <==
/*
 *  Kaidan - A user-friendly XMPP client for every device!
 *
 *  Copyright (C) 2016-2020 Kaidan developers and contributors
 *  (see the LICENSE file for a full list of copyright authors)
 *
 *  Kaidan is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  In addition, as a special exception, the author of Kaidan gives
 *  permission to link the code of its release with the OpenSSL
 *  project's "OpenSSL" library (or with modified versions of it that
 *  use the same license as the "OpenSSL" library), and distribute the
 *  linked executables. You must obey the GNU General Public License in
 *  all respects for all of the code used other than "OpenSSL". If you
 *  modify this file, you may extend this exception to your version of
 *  the file, but you are not obligated to do so.  If you do not wish to
 *  do so, delete this exception statement from your version.
 *
 *  Kaidan is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Kaidan.  If not, see <http://www.gnu.org/licenses/>.
 */

#pragma once

#include <QObject>

/**
 * This is a validator for XMPP account credentials.
 */
class CredentialsValidator : public QObject
{
	Q_OBJECT

public:
	CredentialsValidator(QObject *parent = nullptr);

	/**
	 * Returns true if the given string is a valid JID of an XMPP account.
	 *
	 * @param jid JID to be validated
	 */
	Q_INVOKABLE static bool isAccountJidValid(const QString &jid);

	/**
	 * Returns true if the given string is a valid username.
	 *
	 * @param username username to be validated
	 */
	Q_INVOKABLE static bool isUsernameValid(const QString &username);

	/**
	 * Returns true if the given string is a valid server.
	 *
	 * @param username server to be validated
	 */
	Q_INVOKABLE static bool isServerValid(const QString &server);

	/**
	 * Returns true if the given string is a valid password.
	 *
	 * @param password password to be validated
	 */
	Q_INVOKABLE static bool isPasswordValid(const QString &password);
};
